@@ -3,7 +3,7 @@ from enum import Enum
 from types import SimpleNamespace
 from typing import List
 
-LANGUAGES = {'cpp': 'C++', 'cs': 'C#', 'c': 'C', 'py': 'Python', 'rb': 'Ruby'}
+LANGUAGES = {'cpp': 'C++', 'cs': 'C#', 'c': 'C', 'py': 'Python', 'rb': 'Ruby', 'js': 'JavaScript'}
 
 COMPILE_COMMANDS = {
     'cs': lambda filename: ['mcs', '-optimize', '-nologo', '-out:' + filename + '.o', filename],
@@ -12,6 +12,7 @@ COMPILE_COMMANDS = {
     'py': lambda filename: [['pylint', '--disable=R,C', filename], ['cp', filename, filename + '.o']],
     'py_nl': lambda filename: ['cp', filename, filename + '.o'],
     'rb': lambda filename: ['cp', filename, filename + '.o'],
+    'js': lambda filename: ['cp', filename, filename + '.o'],
 }
 EXEC_COMMANDS = {
     'cs': lambda filename: ['mono', filename],
@@ -20,14 +21,17 @@ EXEC_COMMANDS = {
     'py': lambda filename: ['python3', filename],
     'py_nl': lambda filename: ['python3', filename],
     'rb': lambda filename: ['ruby', filename],
+    'js': lambda filename: ['node', filename],
 }
+COMMON_AVAILABLE_BINARIES = ['env', 'bash', 'sh']
 AVAILABLE_BINARIES = {
-    'cs': ['env', 'bash', 'sh', 'mono', 'mcs'],
-    'cpp': ['env', 'bash', 'sh', 'g++', 'ld', 'as'],
-    'c': ['env', 'bash', 'sh', 'gcc', 'ld', 'as'],
-    'py': ['env', 'bash', 'sh', 'python', 'python3', 'pylint', 'cp'],
-    'py_nl': ['env', 'bash', 'sh', 'python', 'python3', 'cp'],
-    'rb': ['env', 'bash', 'sh', 'ruby', 'cp'],
+    'cs': ['mono', 'mcs'],
+    'cpp': ['g++', 'ld', 'as'],
+    'c': ['gcc', 'ld', 'as'],
+    'py': ['python', 'python3', 'pylint', 'cp'],
+    'py_nl': ['python', 'python3', 'cp'],
+    'rb': ['ruby', 'cp'],
+    'js': ['node', 'cp'],
 }
 
 MY_USER = getpass.getuser()
@@ -68,5 +72,6 @@ class TestResult(SimpleNamespace):
     first_error_test: int
 
 
-__all__ = ['LANGUAGES', 'COMPILE_COMMANDS', 'EXEC_COMMANDS', 'AVAILABLE_BINARIES', 'MY_USER',
-           'TestingException', 'CgroupSetupException', 'ExecStatus', 'ExecResult', 'TestResult']
+__all__ = ['LANGUAGES', 'COMPILE_COMMANDS', 'EXEC_COMMANDS', 'COMMON_AVAILABLE_BINARIES',
+           'AVAILABLE_BINARIES', 'MY_USER', 'TestingException', 'CgroupSetupException',
+           'ExecStatus', 'ExecResult', 'TestResult']
